pub struct InvalidHistoricDate {
pub year: i32,
pub month: Month,
pub day: u8,
}Expand description
Error that is returned if a date is encountered that does not exist in the historic calendar. This may be either because the given day-of-month is not a valid day (for a given combination of month and year) or because the given date falls within the ranges of dates skipped during the Gregorian calendar reform (5 up to and including 14 October 1582).
Fields
year: i32month: Monthday: u8Trait Implementations
Sourceimpl Clone for InvalidHistoricDate
impl Clone for InvalidHistoricDate
Sourcefn clone(&self) -> InvalidHistoricDate
fn clone(&self) -> InvalidHistoricDate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidHistoricDate
impl Debug for InvalidHistoricDate
Sourceimpl From<InvalidHistoricDate> for DateTimeError
impl From<InvalidHistoricDate> for DateTimeError
Sourcefn from(value: InvalidHistoricDate) -> Self
fn from(value: InvalidHistoricDate) -> Self
Converts to this type from the input type.
Sourceimpl<T, P> From<InvalidHistoricDate> for FineDateTimeError<T, P>where
P: Unit,
T: TimeRepresentation,
impl<T, P> From<InvalidHistoricDate> for FineDateTimeError<T, P>where
P: Unit,
T: TimeRepresentation,
Sourcefn from(value: InvalidHistoricDate) -> Self
fn from(value: InvalidHistoricDate) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for InvalidHistoricDate
impl PartialEq for InvalidHistoricDate
impl Copy for InvalidHistoricDate
impl Eq for InvalidHistoricDate
impl StructuralPartialEq for InvalidHistoricDate