pub trait FromDate<Representation>:
FromUnit<SecondsPerDay, Representation>
+ FromUnit<SecondsPerHour, Representation>
+ FromUnit<SecondsPerMinute, Representation>
+ FromUnit<Second, Representation> { }Expand description
Helper trait that is used to indicate that a certain unit can be used to express datetimes. In practice, that just means that it must be able to convert from days, hours, minutes, and seconds.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.