pub type Years<T> = Duration<T, SecondsPerYear>;Expand description
The length of an average year in the Gregorian calendar.
Aliased Type
pub struct Years<T> { /* private fields */ }pub type Years<T> = Duration<T, SecondsPerYear>;The length of an average year in the Gregorian calendar.
pub struct Years<T> { /* private fields */ }