pub enum DateTimeError {
InvalidTimeOfDay {
hour: u8,
minute: u8,
second: u8,
},
NoLeapSecondInsertion {
date: LocalDays<i64>,
hour: u8,
minute: u8,
second: u8,
},
LeapSecondDeletion {
date: LocalDays<i64>,
hour: u8,
minute: u8,
second: u8,
},
NotRepresentable {
date: LocalDays<i64>,
hour: u8,
minute: u8,
second: u8,
},
InvalidHistoricDate {
year: i32,
month: Month,
day: u8,
},
InvalidGregorianDate {
year: i32,
month: Month,
day: u8,
},
InvalidDayOfYear {
year: i32,
day_of_year: u16,
},
}Expand description
Errors that may be returned when combining a calendar date with a time-of-day to create a
TimePoint.
Variants
InvalidTimeOfDay
Returned when the given time-of-day does not exist in general (independent of whether the used time scale has leap seconds).
NoLeapSecondInsertion
Returned when the requested datetime has a 61st second but is not actually situated at a leap second insertion.
LeapSecondDeletion
Returned when the requested datetime does not exist because of a leap second deletion.
NotRepresentable
Returned when the requested datetime could not fit in a TimePoint with the given
Representation.
InvalidHistoricDate
Returned when the requested date is not a valid historic date.
InvalidGregorianDate
Returned when the requested date is not a valid Gregorian date.
InvalidDayOfYear
Returned when the requested day-of-year does not exist in the given year.